@@ -26,7 +26,7 @@ class TDEPopupMenu;
 */
 class KomposeFullscreenWidget : public KomposeTaskContainerWidget
 {
-Q_OBJECT
+TQ_OBJECT
 public:
   KomposeFullscreenWidget( int displayType = KOMPOSEDISPLAY_VIRTUALDESKS ,KomposeLayout *l = 0 );
 
