@@ -77,7 +77,7 @@ KomposePreferences::KomposePreferences()
     TQHBox *hLayXineramaGrabDelay = new TQHBox(xineramaGroupBox);
     TQLabel *xineramaLabel = new TQLabel(i18n("Use screen:"), hLayXineramaGrabDelay);
     m_viewScreen = new TQSpinBox(0, deskwidget.numScreens()-1, 1, hLayXineramaGrabDelay);
-    connect( m_viewScreenAll, SIGNAL(toggled(bool)), m_viewScreen, SLOT(setDisabled(bool)) );
+    connect( m_viewScreenAll, TQ_SIGNAL(toggled(bool)), m_viewScreen, TQ_SLOT(setDisabled(bool)) );
     xineramaLabel->setBuddy(m_viewScreen);
     TQString xineramaHelp = i18n("Specify the screen where Komposé should appear." );
     TQWhatsThis::add( m_viewScreen, xineramaHelp );
@@ -95,7 +95,7 @@ KomposePreferences::KomposePreferences()
   TQString useCompositeHelp = i18n("Making use of the Composite extension of newer X Servers makes the grabbing of screenshots obsolete.\nThe contents of all windows are drawn in back buffers that will be accessed by Komposé\nNote that the Composite implementation of even modern graphic card drivers is still very slow and may make your system pretty unusable.");
   TQWhatsThis::add( useComposite, useCompositeHelp );
   TQToolTip::add( useComposite, useCompositeHelp );
-  connect( useComposite, SIGNAL(toggled(bool)), SLOT(setUseCompositeToggled(bool)) );
+  connect( useComposite, TQ_SIGNAL(toggled(bool)), TQ_SLOT(setUseCompositeToggled(bool)) );
 #else
   TQGroupBox *screenshotsGroupBox = new TQGroupBox( 3, Vertical, i18n("Screenshots"), page1 );
 #endif
@@ -189,20 +189,20 @@ KomposePreferences::KomposePreferences()
   TQString showWindowTitlesHelp = i18n( "Display the name of every window in Komposé" );
   TQWhatsThis::add( showWindowTitles, showWindowTitlesHelp );
   TQToolTip::add( showWindowTitles, showWindowTitlesHelp );
-  connect( showWindowTitles, SIGNAL(toggled(bool)), windowTitleFontBtn, SLOT(setEnabled(bool)) );
-  connect( windowTitleFontBtn, SIGNAL(clicked()), this, SLOT(showWindowTitleFontDialog()) );
+  connect( showWindowTitles, TQ_SIGNAL(toggled(bool)), windowTitleFontBtn, TQ_SLOT(setEnabled(bool)) );
+  connect( windowTitleFontBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(showWindowTitleFontDialog()) );
 
   TQGrid *gridWindowTitlesColor = new TQGrid(2, windowTitleGroupBox);
   // windowTitleFontColorLabel = new TQLabel(windowTitleFontColor, i18n("Text color: "), gridWindowTitlesColor); // FIXME: How to link to a buddy that doesn't yet exist?
   windowTitleFontColorLabel = new TQLabel(i18n("Text color:"), gridWindowTitlesColor);
   windowTitleFontColor = new KColorButton(TQt::black, gridWindowTitlesColor);
-  connect( showWindowTitles, SIGNAL(toggled(bool)), windowTitleFontColorLabel, SLOT(setEnabled(bool)) );
-  connect( showWindowTitles, SIGNAL(toggled(bool)), windowTitleFontColor, SLOT(setEnabled(bool)) );
+  connect( showWindowTitles, TQ_SIGNAL(toggled(bool)), windowTitleFontColorLabel, TQ_SLOT(setEnabled(bool)) );
+  connect( showWindowTitles, TQ_SIGNAL(toggled(bool)), windowTitleFontColor, TQ_SLOT(setEnabled(bool)) );
   showWindowTitleShadow = new TQCheckBox(i18n("Shadow color:"), gridWindowTitlesColor);
   windowTitleFontShadowColor = new KColorButton(TQt::lightGray, gridWindowTitlesColor);
-  connect( showWindowTitles, SIGNAL(toggled(bool)), showWindowTitleShadow, SLOT(setEnabled(bool)) );
-  connect( showWindowTitles, SIGNAL(toggled(bool)), windowTitleFontShadowColor, SLOT(setEnabled(bool)) );
-  connect( showWindowTitleShadow, SIGNAL(toggled(bool)), windowTitleFontShadowColor, SLOT(setEnabled(bool)) );
+  connect( showWindowTitles, TQ_SIGNAL(toggled(bool)), showWindowTitleShadow, TQ_SLOT(setEnabled(bool)) );
+  connect( showWindowTitles, TQ_SIGNAL(toggled(bool)), windowTitleFontShadowColor, TQ_SLOT(setEnabled(bool)) );
+  connect( showWindowTitleShadow, TQ_SIGNAL(toggled(bool)), windowTitleFontShadowColor, TQ_SLOT(setEnabled(bool)) );
 
   page2Layout->addWidget(windowTitleGroupBox);
 
@@ -245,10 +245,10 @@ KomposePreferences::KomposePreferences()
   showIcons = new TQCheckBox(i18n("Show icons"), iconGroupBox);
   iconSize = new TQSlider(0, 3, 1, 0, TQt::Horizontal, iconGroupBox);
   iconSizeDescription = new TQLabel( iconSize, "", iconGroupBox);
-  connect( iconSize, SIGNAL( sliderMoved(int) ), this, SLOT( updateIconSliderDesc(int) ) );
-  connect( iconSize, SIGNAL( valueChanged(int) ), this, SLOT( updateIconSliderDesc(int) ) );
-  connect( showIcons, SIGNAL( toggled(bool) ), iconSize, SLOT( setEnabled(bool) ) );
-  connect( showIcons, SIGNAL( toggled(bool) ), iconSizeDescription, SLOT( setEnabled(bool) ) );
+  connect( iconSize, TQ_SIGNAL( sliderMoved(int) ), this, TQ_SLOT( updateIconSliderDesc(int) ) );
+  connect( iconSize, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( updateIconSliderDesc(int) ) );
+  connect( showIcons, TQ_SIGNAL( toggled(bool) ), iconSize, TQ_SLOT( setEnabled(bool) ) );
+  connect( showIcons, TQ_SIGNAL( toggled(bool) ), iconSizeDescription, TQ_SLOT( setEnabled(bool) ) );
   page2Layout->addWidget(iconGroupBox);
 
   page2Layout->insertStretch(-1);
@@ -275,7 +275,7 @@ KomposePreferences::KomposePreferences()
   page3Layout->addWidget(virtDesksLayoutGroupBox);
 
   desktopTitleFontBtn = new TQPushButton(i18n("Select Desktop Names Font..."), virtDesksLayoutGroupBox);
-  connect( desktopTitleFontBtn, SIGNAL(clicked()), this, SLOT(showDesktopTitleFontDialog()) );
+  connect( desktopTitleFontBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(showDesktopTitleFontDialog()) );
 
   page3Layout->insertStretch(-1);
 
