@@ -25,7 +25,7 @@ class TDEPopupMenu;
 */
 class KomposeSysTray : public KSystemTray
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   KomposeSysTray(TQWidget *parent = 0, const char *name = 0);
   ~KomposeSysTray();
